#! /usr/bin/python
#
# This script parses emails and generates entries suitable for inclusion here:
#
# <https://community.openvpn.net/openvpn/wiki/Patches>
#
# The email is passed to the script using pipes. You have least two deployment
# options:
#
# 1) Use Mozilla Thunderbird and ImportExportTools plugin
#
#    Save the email as an MBOX file and pass it to the script like this:
#
#    $ cat file.mbox|./parseOvpn.py
#
# 2) Copy-and-paste the email source to a text editor and run parseOvpn.py as
#    an external command
#
#    In gedit you'd first enable the "External Tools" plugin. Then you'd add a
#    new Tool that runs the following:
#
#    #!/bin/sh
#    parseOvpn.py
import email.header

import email
import email.utils
import sys
import time

gmane='http://news.gmane.org/find-root.php?message_id=%s'

lineformat='|| %(date)s ||[[%(url)s| %(title)s ]] || %(author)s || ||'

def decode_header(h):
    d = email.header.decode_header(h)
    r =""
    for t,e in d:
        if r:
            r+=" "
        if e:
            r += t.decode(e)
        else:
            r += t
    return r
        

def main():
    msg = email.message_from_file(sys.stdin)

    d= {}

    d['url'] = gmane % msg['Message-Id']
    d['title'] = decode_header(msg['Subject']).replace( '\t',"").replace('\n',"")
    d['title'] = d['title'].replace('[Openvpn-devel] ',"")

    t = email.utils.parsedate(msg['Date'])
    d['date'] = time.strftime("%Y-%m-%d",t)
    d['author'] = decode_header(msg['From'])

    print lineformat % d

if __name__=='__main__':
    main()
